from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
import dataclasses

@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodInputSchema:
    type: str
    schema: Dict[str, Any]
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodOutputSchema:
    type: str
    schema: Dict[str, Any]
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodScopes:
    object: str
    id: str
    scope: str
    name: str
    description: Optional[str] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethod:
    object: str
    id: str
    type: str
    key: str
    name: str
    capabilities: Dict[str, Any]
    provider_id: str
    provider_specification_id: str
    created_at: datetime
    updated_at: datetime
    description: Optional[str] = None
    input_schema: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodInputSchema] = None
    output_schema: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodOutputSchema] = None
    scopes: Optional[List[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodScopes]] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputDeployment:
    object: str
    id: str
    is_default: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputCredentials:
    object: str
    id: str
    type: str
    is_default: bool
    is_managed: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigDeploymentPreview:
    object: str
    id: str
    is_default: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigCredentials:
    object: str
    id: str
    type: str
    is_default: bool
    is_managed: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodInputSchema:
    type: str
    schema: Dict[str, Any]
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodOutputSchema:
    type: str
    schema: Dict[str, Any]
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodScopes:
    object: str
    id: str
    scope: str
    name: str
    description: Optional[str] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethod:
    object: str
    id: str
    type: str
    key: str
    name: str
    capabilities: Dict[str, Any]
    provider_id: str
    provider_specification_id: str
    created_at: datetime
    updated_at: datetime
    description: Optional[str] = None
    input_schema: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodInputSchema] = None
    output_schema: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodOutputSchema] = None
    scopes: Optional[List[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodScopes]] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfig:
    object: str
    id: str
    type: str
    source: str
    status: str
    is_default: bool
    provider_id: str
    auth_method: DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethod
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
    deployment_preview: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigDeploymentPreview] = None
    credentials: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigCredentials] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigDeployment:
    object: str
    id: str
    is_default: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVaultDeployment:
    object: str
    id: str
    is_default: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVault:
    object: str
    id: str
    name: str
    provider_id: str
    created_at: datetime
    updated_at: datetime
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
    deployment: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVaultDeployment] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfig:
    object: str
    id: str
    is_default: bool
    provider_id: str
    specification_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
    deployment: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigDeployment] = None
    from_vault: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVault] = None
@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput:
    object: str
    id: str
    type: str
    status: str
    url: str
    provider_id: str
    auth_method: DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethod
    ui_mode: str
    created_at: datetime
    updated_at: datetime
    expires_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
    deployment: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputDeployment] = None
    credentials: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputCredentials] = None
    auth_config: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfig] = None
    config: Optional[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfig] = None
    redirect_url: Optional[str] = None


class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodInputSchema:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodInputSchema:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodInputSchema(
        type=data.get('type'),
        schema=data.get('schema')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodInputSchema, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodOutputSchema:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodOutputSchema:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodOutputSchema(
        type=data.get('type'),
        schema=data.get('schema')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodOutputSchema, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodScopes:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodScopes:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodScopes(
        object=data.get('object'),
        id=data.get('id'),
        scope=data.get('scope'),
        name=data.get('name'),
        description=data.get('description')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodScopes, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethod:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethod:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethod(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        key=data.get('key'),
        name=data.get('name'),
        description=data.get('description'),
        capabilities=data.get('capabilities'),
        input_schema=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodInputSchema.from_dict(data.get('input_schema')) if data.get('input_schema') else None,
        output_schema=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodOutputSchema.from_dict(data.get('output_schema')) if data.get('output_schema') else None,
        scopes=[mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethodScopes.from_dict(item) for item in data.get('scopes', []) if item],
        provider_id=data.get('provider_id'),
        provider_specification_id=data.get('provider_specification_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethod, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputDeployment:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputDeployment:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputDeployment(
        object=data.get('object'),
        id=data.get('id'),
        is_default=data.get('is_default'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputDeployment, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputCredentials:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputCredentials:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputCredentials(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        is_default=data.get('is_default'),
        is_managed=data.get('is_managed'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputCredentials, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigDeploymentPreview:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigDeploymentPreview:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigDeploymentPreview(
        object=data.get('object'),
        id=data.get('id'),
        is_default=data.get('is_default'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigDeploymentPreview, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigCredentials:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigCredentials:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigCredentials(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        is_default=data.get('is_default'),
        is_managed=data.get('is_managed'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigCredentials, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodInputSchema:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodInputSchema:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodInputSchema(
        type=data.get('type'),
        schema=data.get('schema')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodInputSchema, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodOutputSchema:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodOutputSchema:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodOutputSchema(
        type=data.get('type'),
        schema=data.get('schema')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodOutputSchema, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodScopes:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodScopes:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodScopes(
        object=data.get('object'),
        id=data.get('id'),
        scope=data.get('scope'),
        name=data.get('name'),
        description=data.get('description')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodScopes, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethod:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethod:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethod(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        key=data.get('key'),
        name=data.get('name'),
        description=data.get('description'),
        capabilities=data.get('capabilities'),
        input_schema=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodInputSchema.from_dict(data.get('input_schema')) if data.get('input_schema') else None,
        output_schema=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodOutputSchema.from_dict(data.get('output_schema')) if data.get('output_schema') else None,
        scopes=[mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethodScopes.from_dict(item) for item in data.get('scopes', []) if item],
        provider_id=data.get('provider_id'),
        provider_specification_id=data.get('provider_specification_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethod, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfig:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfig:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfig(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        source=data.get('source'),
        status=data.get('status'),
        is_default=data.get('is_default'),
        provider_id=data.get('provider_id'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        deployment_preview=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigDeploymentPreview.from_dict(data.get('deployment_preview')) if data.get('deployment_preview') else None,
        credentials=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigCredentials.from_dict(data.get('credentials')) if data.get('credentials') else None,
        auth_method=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfigAuthMethod.from_dict(data.get('auth_method')) if data.get('auth_method') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfig, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigDeployment:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigDeployment:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigDeployment(
        object=data.get('object'),
        id=data.get('id'),
        is_default=data.get('is_default'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigDeployment, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVaultDeployment:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVaultDeployment:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVaultDeployment(
        object=data.get('object'),
        id=data.get('id'),
        is_default=data.get('is_default'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVaultDeployment, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVault:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVault:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVault(
        object=data.get('object'),
        id=data.get('id'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        deployment=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVaultDeployment.from_dict(data.get('deployment')) if data.get('deployment') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVault, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfig:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfig:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfig(
        object=data.get('object'),
        id=data.get('id'),
        is_default=data.get('is_default'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        specification_id=data.get('specification_id'),
        deployment=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigDeployment.from_dict(data.get('deployment')) if data.get('deployment') else None,
        from_vault=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfigFromVault.from_dict(data.get('from_vault')) if data.get('from_vault') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfig, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutput:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        status=data.get('status'),
        url=data.get('url'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        auth_method=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthMethod.from_dict(data.get('auth_method')) if data.get('auth_method') else None,
        deployment=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputDeployment.from_dict(data.get('deployment')) if data.get('deployment') else None,
        credentials=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputCredentials.from_dict(data.get('credentials')) if data.get('credentials') else None,
        auth_config=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputAuthConfig.from_dict(data.get('auth_config')) if data.get('auth_config') else None,
        config=mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutputConfig.from_dict(data.get('config')) if data.get('config') else None,
        ui_mode=data.get('ui_mode'),
        redirect_url=data.get('redirect_url'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None,
        expires_at=datetime.fromisoformat(data.get('expires_at').replace('Z', '+00:00')) if data.get('expires_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)

@dataclass
class DashboardInstanceProviderDeploymentsSetupSessionsCreateBody:
    provider_id: str
    provider_deployment_id: Optional[str] = None
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
    provider_auth_method_id: Optional[str] = None
    provider_auth_credentials_id: Optional[str] = None
    redirect_url: Optional[str] = None


class mapDashboardInstanceProviderDeploymentsSetupSessionsCreateBody:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsSetupSessionsCreateBody:
        return DashboardInstanceProviderDeploymentsSetupSessionsCreateBody(
        provider_id=data.get('provider_id'),
        provider_deployment_id=data.get('provider_deployment_id'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_auth_method_id=data.get('provider_auth_method_id'),
        provider_auth_credentials_id=data.get('provider_auth_credentials_id'),
        redirect_url=data.get('redirect_url')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsSetupSessionsCreateBody, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)




from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
from metorial.utils import parse_iso_datetime
import dataclasses


@dataclass
class DashboardInstanceCallbacksDestinationsListOutputItemsWebhookDestination:
  url: str
  signing_secret: str


@dataclass
class DashboardInstanceCallbacksDestinationsListOutputItems:
  object: str
  id: str
  type: str
  name: str
  description: str
  callbacks: Dict[str, Any]
  created_at: datetime
  webhook_destination: Optional[
    DashboardInstanceCallbacksDestinationsListOutputItemsWebhookDestination
  ] = None


@dataclass
class DashboardInstanceCallbacksDestinationsListOutputPagination:
  has_more_before: bool
  has_more_after: bool


@dataclass
class DashboardInstanceCallbacksDestinationsListOutput:
  items: List[DashboardInstanceCallbacksDestinationsListOutputItems]
  pagination: DashboardInstanceCallbacksDestinationsListOutputPagination


class mapDashboardInstanceCallbacksDestinationsListOutputItemsWebhookDestination:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> DashboardInstanceCallbacksDestinationsListOutputItemsWebhookDestination:
    return DashboardInstanceCallbacksDestinationsListOutputItemsWebhookDestination(
      url=data.get("url"), signing_secret=data.get("signing_secret")
    )

  @staticmethod
  def to_dict(
    value: Union[
      DashboardInstanceCallbacksDestinationsListOutputItemsWebhookDestination,
      Dict[str, Any],
      None,
    ]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceCallbacksDestinationsListOutputItems:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> DashboardInstanceCallbacksDestinationsListOutputItems:
    return DashboardInstanceCallbacksDestinationsListOutputItems(
      object=data.get("object"),
      id=data.get("id"),
      type=data.get("type"),
      name=data.get("name"),
      description=data.get("description"),
      webhook_destination=mapDashboardInstanceCallbacksDestinationsListOutputItemsWebhookDestination.from_dict(
        data.get("webhook_destination")
      )
      if data.get("webhook_destination")
      else None,
      callbacks=data.get("callbacks"),
      created_at=parse_iso_datetime(data.get("created_at"))
      if data.get("created_at")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[
      DashboardInstanceCallbacksDestinationsListOutputItems, Dict[str, Any], None
    ]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceCallbacksDestinationsListOutputPagination:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> DashboardInstanceCallbacksDestinationsListOutputPagination:
    return DashboardInstanceCallbacksDestinationsListOutputPagination(
      has_more_before=data.get("has_more_before"),
      has_more_after=data.get("has_more_after"),
    )

  @staticmethod
  def to_dict(
    value: Union[
      DashboardInstanceCallbacksDestinationsListOutputPagination, Dict[str, Any], None
    ]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    return dataclasses.asdict(value)


class mapDashboardInstanceCallbacksDestinationsListOutput:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> DashboardInstanceCallbacksDestinationsListOutput:
    return DashboardInstanceCallbacksDestinationsListOutput(
      items=[
        mapDashboardInstanceCallbacksDestinationsListOutputItems.from_dict(item)
        for item in data.get("items", [])
        if item
      ],
      pagination=mapDashboardInstanceCallbacksDestinationsListOutputPagination.from_dict(
        data.get("pagination")
      )
      if data.get("pagination")
      else None,
    )

  @staticmethod
  def to_dict(
    value: Union[DashboardInstanceCallbacksDestinationsListOutput, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    # assume dataclass for generated models
    return dataclasses.asdict(value)


@dataclass
class DashboardInstanceCallbacksDestinationsListQuery:
  limit: Optional[float] = None
  after: Optional[str] = None
  before: Optional[str] = None
  cursor: Optional[str] = None
  order: Optional[str] = None
  callback_id: Optional[Union[str, List[str]]] = None


class mapDashboardInstanceCallbacksDestinationsListQuery:
  @staticmethod
  def from_dict(
    data: Dict[str, Any]
  ) -> DashboardInstanceCallbacksDestinationsListQuery:
    return DashboardInstanceCallbacksDestinationsListQuery(
      limit=data.get("limit"),
      after=data.get("after"),
      before=data.get("before"),
      cursor=data.get("cursor"),
      order=data.get("order"),
      callback_id=data.get("callback_id"),
    )

  @staticmethod
  def to_dict(
    value: Union[DashboardInstanceCallbacksDestinationsListQuery, Dict[str, Any], None]
  ) -> Optional[Dict[str, Any]]:
    if value is None:
      return None
    if isinstance(value, dict):
      return value
    # assume dataclass for generated models
    return dataclasses.asdict(value)



from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
import dataclasses

@dataclass
class DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroupsGroup:
    object: str
    id: str
    status: str
    name: str
    is_default: bool
    sso_group_ids: List[str]
    created_at: datetime
    updated_at: datetime
    description: Optional[str] = None
@dataclass
class DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroups:
    object: str
    group: DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroupsGroup
    assigned_via: str
@dataclass
class DashboardInstancePortalsConsumerProfilesUnassignGroupsOutput:
    object: str
    id: str
    name: str
    email: str
    image_url: str
    consumer_id: str
    created_at: datetime
    updated_at: datetime
    groups: Optional[List[DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroups]] = None


class mapDashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroupsGroup:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroupsGroup:
        return DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroupsGroup(
        object=data.get('object'),
        id=data.get('id'),
        status=data.get('status'),
        name=data.get('name'),
        description=data.get('description'),
        is_default=data.get('is_default'),
        sso_group_ids=data.get('sso_group_ids', []),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroupsGroup, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroups:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroups:
        return DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroups(
        object=data.get('object'),
        group=mapDashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroupsGroup.from_dict(data.get('group')) if data.get('group') else None,
        assigned_via=data.get('assigned_via')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroups, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstancePortalsConsumerProfilesUnassignGroupsOutput:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstancePortalsConsumerProfilesUnassignGroupsOutput:
        return DashboardInstancePortalsConsumerProfilesUnassignGroupsOutput(
        object=data.get('object'),
        id=data.get('id'),
        name=data.get('name'),
        email=data.get('email'),
        image_url=data.get('image_url'),
        groups=[mapDashboardInstancePortalsConsumerProfilesUnassignGroupsOutputGroups.from_dict(item) for item in data.get('groups', []) if item],
        consumer_id=data.get('consumer_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstancePortalsConsumerProfilesUnassignGroupsOutput, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)

@dataclass
class DashboardInstancePortalsConsumerProfilesUnassignGroupsBody:
    group_ids: List[str]


class mapDashboardInstancePortalsConsumerProfilesUnassignGroupsBody:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstancePortalsConsumerProfilesUnassignGroupsBody:
        return DashboardInstancePortalsConsumerProfilesUnassignGroupsBody(
        group_ids=data.get('group_ids', [])
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstancePortalsConsumerProfilesUnassignGroupsBody, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)




from .resources import *
from .endpoints import *

# Type exports for better discoverability
# Generated type exports
# These types are automatically exported for better IDE support

# Type classes
# ConsumerProfileGetOutput
# ConsumerProfileGroupsListOutput
# ConsumerProfileGroupsListQuery
# ConsumerProvidersDeployBody
# ConsumerProvidersDeployOutput
# ConsumerProvidersGetOutput
# ConsumerProvidersGetSetupOutput
# ConsumerProvidersListOutput
# ConsumerProvidersListQuery
# ConsumerProvidersRequestAccessBody
# ConsumerProvidersRequestAccessOutput
# ConsumerProvidersSetupBody
# ConsumerProvidersSetupOutput
# ConsumerSessionGetOutput
# ConsumerSessionLogoutOutput
# DashboardInstanceCallbacksCreateBody
# DashboardInstanceCallbacksCreateOutput
# DashboardInstanceCallbacksDeleteOutput
# DashboardInstanceCallbacksDestinationsCreateBody
# DashboardInstanceCallbacksDestinationsCreateOutput
# DashboardInstanceCallbacksDestinationsDeleteOutput
# DashboardInstanceCallbacksDestinationsGetOutput
# DashboardInstanceCallbacksDestinationsListOutput
# DashboardInstanceCallbacksDestinationsListQuery
# DashboardInstanceCallbacksDestinationsUpdateBody
# DashboardInstanceCallbacksDestinationsUpdateOutput
# DashboardInstanceCallbacksEventsGetOutput
# DashboardInstanceCallbacksEventsListOutput
# DashboardInstanceCallbacksEventsListQuery
# DashboardInstanceCallbacksGetOutput
# DashboardInstanceCallbacksInstancesCreateBody
# DashboardInstanceCallbacksInstancesCreateOutput
# DashboardInstanceCallbacksInstancesDeleteOutput
# DashboardInstanceCallbacksInstancesListOutput
# DashboardInstanceCallbacksInstancesListQuery
# DashboardInstanceCallbacksListOutput
# DashboardInstanceCallbacksListQuery
# DashboardInstanceCallbacksNotificationsGetOutput
# DashboardInstanceCallbacksNotificationsListOutput
# DashboardInstanceCallbacksNotificationsListQuery
# DashboardInstanceCallbacksUpdateBody
# DashboardInstanceCallbacksUpdateOutput
# DashboardInstanceCustomProvidersCommitsCreateBody
# DashboardInstanceCustomProvidersCommitsCreateOutput
# DashboardInstanceCustomProvidersCommitsGetOutput
# DashboardInstanceCustomProvidersCommitsListOutput
# DashboardInstanceCustomProvidersCommitsListQuery
# DashboardInstanceCustomProvidersCreateBody
# DashboardInstanceCustomProvidersCreateOutput
# DashboardInstanceCustomProvidersDeploymentsGetLogsOutput
# DashboardInstanceCustomProvidersDeploymentsGetOutput
# DashboardInstanceCustomProvidersDeploymentsListOutput
# DashboardInstanceCustomProvidersDeploymentsListQuery
# DashboardInstanceCustomProvidersEnvironmentsGetOutput
# DashboardInstanceCustomProvidersEnvironmentsListOutput
# DashboardInstanceCustomProvidersEnvironmentsListQuery
# DashboardInstanceCustomProvidersGetOutput
# DashboardInstanceCustomProvidersListOutput
# DashboardInstanceCustomProvidersListQuery
# DashboardInstanceCustomProvidersUpdateBody
# DashboardInstanceCustomProvidersUpdateOutput
# DashboardInstanceCustomProvidersVersionsCreateBody
# DashboardInstanceCustomProvidersVersionsCreateOutput
# DashboardInstanceCustomProvidersVersionsGetOutput
# DashboardInstanceCustomProvidersVersionsListOutput
# DashboardInstanceCustomProvidersVersionsListQuery
# DashboardInstanceFileLinksCreateBody
# DashboardInstanceFileLinksCreateOutput
# DashboardInstanceFileLinksDeleteOutput
# DashboardInstanceFileLinksGetOutput
# DashboardInstanceFileLinksListOutput
# DashboardInstanceFileLinksListQuery
# DashboardInstanceFilesDeleteOutput
# DashboardInstanceFilesGetOutput
# DashboardInstanceFilesListOutput
# DashboardInstanceFilesListQuery
# DashboardInstanceIdentitiesCreateBody
# DashboardInstanceIdentitiesCreateOutput
# DashboardInstanceIdentitiesCredentialsCreateBody
# DashboardInstanceIdentitiesCredentialsCreateOutput
# DashboardInstanceIdentitiesCredentialsDeleteOutput
# DashboardInstanceIdentitiesCredentialsGetOutput
# DashboardInstanceIdentitiesCredentialsListOutput
# DashboardInstanceIdentitiesCredentialsListQuery
# DashboardInstanceIdentitiesCredentialsUpdateBody
# DashboardInstanceIdentitiesCredentialsUpdateOutput
# DashboardInstanceIdentitiesDelegationConfigsCreateBody
# DashboardInstanceIdentitiesDelegationConfigsCreateOutput
# DashboardInstanceIdentitiesDelegationConfigsDeleteOutput
# DashboardInstanceIdentitiesDelegationConfigsGetOutput
# DashboardInstanceIdentitiesDelegationConfigsListOutput
# DashboardInstanceIdentitiesDelegationConfigsListQuery
# DashboardInstanceIdentitiesDelegationConfigsUpdateBody
# DashboardInstanceIdentitiesDelegationConfigsUpdateOutput
# DashboardInstanceIdentitiesDelegationRequestsApproveOutput
# DashboardInstanceIdentitiesDelegationRequestsApproveQuery
# DashboardInstanceIdentitiesDelegationRequestsCreateBody
# DashboardInstanceIdentitiesDelegationRequestsCreateOutput
# DashboardInstanceIdentitiesDelegationRequestsDenyOutput
# DashboardInstanceIdentitiesDelegationRequestsDenyQuery
# DashboardInstanceIdentitiesDelegationRequestsGetOutput
# DashboardInstanceIdentitiesDelegationRequestsGetQuery
# DashboardInstanceIdentitiesDelegationRequestsListOutput
# DashboardInstanceIdentitiesDelegationRequestsListQuery
# DashboardInstanceIdentitiesDelegationsCreateBody
# DashboardInstanceIdentitiesDelegationsCreateOutput
# DashboardInstanceIdentitiesDelegationsGetOutput
# DashboardInstanceIdentitiesDelegationsListOutput
# DashboardInstanceIdentitiesDelegationsListQuery
# DashboardInstanceIdentitiesDelegationsRevokeOutput
# DashboardInstanceIdentitiesDeleteOutput
# DashboardInstanceIdentitiesGetOutput
# DashboardInstanceIdentitiesListOutput
# DashboardInstanceIdentitiesListQuery
# DashboardInstanceIdentitiesUpdateBody
# DashboardInstanceIdentitiesUpdateOutput
# DashboardInstanceIdentityActorsCreateBody
# DashboardInstanceIdentityActorsCreateOutput
# DashboardInstanceIdentityActorsDeleteOutput
# DashboardInstanceIdentityActorsGetOutput
# DashboardInstanceIdentityActorsListOutput
# DashboardInstanceIdentityActorsListQuery
# DashboardInstanceIdentityActorsUpdateBody
# DashboardInstanceIdentityActorsUpdateOutput
# DashboardInstanceInstanceGetOutput
# DashboardInstanceMagicMcpGroupsAddServersBody
# DashboardInstanceMagicMcpGroupsAddServersOutput
# DashboardInstanceMagicMcpGroupsCreateBody
# DashboardInstanceMagicMcpGroupsCreateOutput
# DashboardInstanceMagicMcpGroupsDeleteOutput
# DashboardInstanceMagicMcpGroupsGetOutput
# DashboardInstanceMagicMcpGroupsListOutput
# DashboardInstanceMagicMcpGroupsListQuery
# DashboardInstanceMagicMcpGroupsRemoveServersBody
# DashboardInstanceMagicMcpGroupsRemoveServersOutput
# DashboardInstanceMagicMcpGroupsUpdateBody
# DashboardInstanceMagicMcpGroupsUpdateOutput
# DashboardInstanceMagicMcpServersCreateBody
# DashboardInstanceMagicMcpServersCreateOutput
# DashboardInstanceMagicMcpServersDeleteOutput
# DashboardInstanceMagicMcpServersGetOutput
# DashboardInstanceMagicMcpServersListOutput
# DashboardInstanceMagicMcpServersListQuery
# DashboardInstanceMagicMcpServersUpdateBody
# DashboardInstanceMagicMcpServersUpdateOutput
# DashboardInstanceMagicMcpSessionsGetOutput
# DashboardInstanceMagicMcpSessionsListOutput
# DashboardInstanceMagicMcpSessionsListQuery
# DashboardInstanceMagicMcpTokensAddGroupsBody
# DashboardInstanceMagicMcpTokensAddGroupsOutput
# DashboardInstanceMagicMcpTokensCreateBody
# DashboardInstanceMagicMcpTokensCreateOutput
# DashboardInstanceMagicMcpTokensDeleteOutput
# DashboardInstanceMagicMcpTokensGetOutput
# DashboardInstanceMagicMcpTokensListOutput
# DashboardInstanceMagicMcpTokensListQuery
# DashboardInstanceMagicMcpTokensRemoveGroupsBody
# DashboardInstanceMagicMcpTokensRemoveGroupsOutput
# DashboardInstanceMagicMcpTokensUpdateBody
# DashboardInstanceMagicMcpTokensUpdateOutput
# DashboardInstancePortalsCreateBody
# DashboardInstancePortalsCreateOutput
# DashboardInstancePortalsDeleteOutput
# DashboardInstancePortalsGetOutput
# DashboardInstancePortalsListOutput
# DashboardInstancePortalsListQuery
# DashboardInstancePortalsUpdateBody
# DashboardInstancePortalsUpdateOutput
# DashboardInstanceProviderCategoriesGetOutput
# DashboardInstanceProviderCategoriesListOutput
# DashboardInstanceProviderCategoriesListQuery
# DashboardInstanceProviderCollectionsGetOutput
# DashboardInstanceProviderCollectionsListOutput
# DashboardInstanceProviderCollectionsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsDeleteOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsExportsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsExportsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsCreateBody
# DashboardInstanceProviderDeploymentsAuthConfigsImportsCreateOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaQuery
# DashboardInstanceProviderDeploymentsAuthConfigsImportsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsImportsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsListOutput
# DashboardInstanceProviderDeploymentsAuthConfigsListQuery
# DashboardInstanceProviderDeploymentsAuthConfigsUpdateBody
# DashboardInstanceProviderDeploymentsAuthConfigsUpdateOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsCreateBody
# DashboardInstanceProviderDeploymentsAuthCredentialsCreateOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsDeleteOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsGetOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsListOutput
# DashboardInstanceProviderDeploymentsAuthCredentialsListQuery
# DashboardInstanceProviderDeploymentsAuthCredentialsUpdateBody
# DashboardInstanceProviderDeploymentsAuthCredentialsUpdateOutput
# DashboardInstanceProviderDeploymentsConfigVaultsCreateBody
# DashboardInstanceProviderDeploymentsConfigVaultsCreateOutput
# DashboardInstanceProviderDeploymentsConfigVaultsDeleteOutput
# DashboardInstanceProviderDeploymentsConfigVaultsGetOutput
# DashboardInstanceProviderDeploymentsConfigVaultsListOutput
# DashboardInstanceProviderDeploymentsConfigVaultsListQuery
# DashboardInstanceProviderDeploymentsConfigVaultsUpdateBody
# DashboardInstanceProviderDeploymentsConfigVaultsUpdateOutput
# DashboardInstanceProviderDeploymentsConfigsCreateBody
# DashboardInstanceProviderDeploymentsConfigsCreateOutput
# DashboardInstanceProviderDeploymentsConfigsDeleteOutput
# DashboardInstanceProviderDeploymentsConfigsGetConfigSchemaOutput
# DashboardInstanceProviderDeploymentsConfigsGetConfigSchemaQuery
# DashboardInstanceProviderDeploymentsConfigsGetOutput
# DashboardInstanceProviderDeploymentsConfigsListOutput
# DashboardInstanceProviderDeploymentsConfigsListQuery
# DashboardInstanceProviderDeploymentsConfigsUpdateBody
# DashboardInstanceProviderDeploymentsConfigsUpdateOutput
# DashboardInstanceProviderDeploymentsCreateBody
# DashboardInstanceProviderDeploymentsCreateOutput
# DashboardInstanceProviderDeploymentsDeleteOutput
# DashboardInstanceProviderDeploymentsGetOutput
# DashboardInstanceProviderDeploymentsListOutput
# DashboardInstanceProviderDeploymentsListQuery
# DashboardInstanceProviderDeploymentsSetupSessionsCreateBody
# DashboardInstanceProviderDeploymentsSetupSessionsCreateOutput
# DashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput
# DashboardInstanceProviderDeploymentsSetupSessionsGetOutput
# DashboardInstanceProviderDeploymentsSetupSessionsListOutput
# DashboardInstanceProviderDeploymentsSetupSessionsListQuery
# DashboardInstanceProviderDeploymentsSetupSessionsUpdateBody
# DashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput
# DashboardInstanceProviderDeploymentsUpdateBody
# DashboardInstanceProviderDeploymentsUpdateOutput
# DashboardInstanceProviderGroupsAddListingBody
# DashboardInstanceProviderGroupsAddListingOutput
# DashboardInstanceProviderGroupsCreateBody
# DashboardInstanceProviderGroupsCreateOutput
# DashboardInstanceProviderGroupsGetOutput
# DashboardInstanceProviderGroupsListOutput
# DashboardInstanceProviderGroupsListQuery
# DashboardInstanceProviderGroupsRemoveListingOutput
# DashboardInstanceProviderGroupsUpdateBody
# DashboardInstanceProviderGroupsUpdateOutput
# DashboardInstanceProviderListingsGetOutput
# DashboardInstanceProviderListingsListOutput
# DashboardInstanceProviderListingsListQuery
# DashboardInstanceProviderRunsGetLogsOutput
# DashboardInstanceProviderRunsGetOutput
# DashboardInstanceProviderRunsListOutput
# DashboardInstanceProviderRunsListQuery
# DashboardInstanceProviderTemplatesCreateBody
# DashboardInstanceProviderTemplatesCreateOutput
# DashboardInstanceProviderTemplatesDeleteOutput
# DashboardInstanceProviderTemplatesGetOutput
# DashboardInstanceProviderTemplatesListOutput
# DashboardInstanceProviderTemplatesListQuery
# DashboardInstanceProviderTemplatesUpdateBody
# DashboardInstanceProviderTemplatesUpdateOutput
# DashboardInstanceProvidersAuthMethodsGetOutput
# DashboardInstanceProvidersAuthMethodsListOutput
# DashboardInstanceProvidersAuthMethodsListQuery
# DashboardInstanceProvidersGetOutput
# DashboardInstanceProvidersListOutput
# DashboardInstanceProvidersListQuery
# DashboardInstanceProvidersSpecificationsGetOutput
# DashboardInstanceProvidersSpecificationsListOutput
# DashboardInstanceProvidersSpecificationsListQuery
# DashboardInstanceProvidersToolsGetOutput
# DashboardInstanceProvidersToolsListOutput
# DashboardInstanceProvidersToolsListQuery
# DashboardInstanceProvidersTriggersGetOutput
# DashboardInstanceProvidersTriggersListOutput
# DashboardInstanceProvidersTriggersListQuery
# DashboardInstanceProvidersVersionsGetOutput
# DashboardInstanceProvidersVersionsListOutput
# DashboardInstanceProvidersVersionsListQuery
# DashboardInstancePublishersGetOutput
# DashboardInstancePublishersListOutput
# DashboardInstancePublishersListQuery
# DashboardInstanceSessionTemplatesCreateBody
# DashboardInstanceSessionTemplatesCreateOutput
# DashboardInstanceSessionTemplatesGetOutput
# DashboardInstanceSessionTemplatesListOutput
# DashboardInstanceSessionTemplatesListQuery
# DashboardInstanceSessionTemplatesProvidersCreateBody
# DashboardInstanceSessionTemplatesProvidersCreateOutput
# DashboardInstanceSessionTemplatesProvidersDeleteOutput
# DashboardInstanceSessionTemplatesProvidersGetOutput
# DashboardInstanceSessionTemplatesProvidersListOutput
# DashboardInstanceSessionTemplatesProvidersListQuery
# DashboardInstanceSessionTemplatesProvidersUpdateBody
# DashboardInstanceSessionTemplatesProvidersUpdateOutput
# DashboardInstanceSessionTemplatesUpdateBody
# DashboardInstanceSessionTemplatesUpdateOutput
# DashboardInstanceSessionsConnectionsGetOutput
# DashboardInstanceSessionsConnectionsListOutput
# DashboardInstanceSessionsConnectionsListQuery
# DashboardInstanceSessionsCreateBody
# DashboardInstanceSessionsCreateOutput
# DashboardInstanceSessionsErrorGroupsGetOutput
# DashboardInstanceSessionsErrorGroupsListOutput
# DashboardInstanceSessionsErrorGroupsListQuery
# DashboardInstanceSessionsErrorsGetOutput
# DashboardInstanceSessionsErrorsListOutput
# DashboardInstanceSessionsErrorsListQuery
# DashboardInstanceSessionsEventsGetOutput
# DashboardInstanceSessionsEventsListOutput
# DashboardInstanceSessionsEventsListQuery
# DashboardInstanceSessionsGetOutput
# DashboardInstanceSessionsListOutput
# DashboardInstanceSessionsListQuery
# DashboardInstanceSessionsMessagesGetOutput
# DashboardInstanceSessionsMessagesListOutput
# DashboardInstanceSessionsMessagesListQuery
# DashboardInstanceSessionsParticipantsGetOutput
# DashboardInstanceSessionsParticipantsListOutput
# DashboardInstanceSessionsParticipantsListQuery
# DashboardInstanceSessionsProvidersCreateBody
# DashboardInstanceSessionsProvidersCreateOutput
# DashboardInstanceSessionsProvidersDeleteOutput
# DashboardInstanceSessionsProvidersGetOutput
# DashboardInstanceSessionsProvidersListOutput
# DashboardInstanceSessionsProvidersListQuery
# DashboardInstanceSessionsProvidersUpdateBody
# DashboardInstanceSessionsProvidersUpdateOutput
# DashboardInstanceSessionsUpdateBody
# DashboardInstanceSessionsUpdateOutput
# DashboardInstanceToolCallsCreateBody
# DashboardInstanceToolCallsCreateOutput
# DashboardInstanceToolCallsGetOutput
# DashboardInstanceToolCallsListOutput
# DashboardInstanceToolCallsListQuery
# InstancesGetOutput
# InstancesListOutput
# TokenGetOutput

# Mapper classes
# mapConsumerProfileGetOutput
# mapConsumerProfileGroupsListOutput
# mapConsumerProfileGroupsListQuery
# mapConsumerProvidersDeployBody
# mapConsumerProvidersDeployOutput
# mapConsumerProvidersGetOutput
# mapConsumerProvidersGetSetupOutput
# mapConsumerProvidersListOutput
# mapConsumerProvidersListQuery
# mapConsumerProvidersRequestAccessBody
# mapConsumerProvidersRequestAccessOutput
# mapConsumerProvidersSetupBody
# mapConsumerProvidersSetupOutput
# mapConsumerSessionGetOutput
# mapConsumerSessionLogoutOutput
# mapDashboardInstanceCallbacksCreateBody
# mapDashboardInstanceCallbacksCreateOutput
# mapDashboardInstanceCallbacksDeleteOutput
# mapDashboardInstanceCallbacksDestinationsCreateBody
# mapDashboardInstanceCallbacksDestinationsCreateOutput
# mapDashboardInstanceCallbacksDestinationsDeleteOutput
# mapDashboardInstanceCallbacksDestinationsGetOutput
# mapDashboardInstanceCallbacksDestinationsListOutput
# mapDashboardInstanceCallbacksDestinationsListQuery
# mapDashboardInstanceCallbacksDestinationsUpdateBody
# mapDashboardInstanceCallbacksDestinationsUpdateOutput
# mapDashboardInstanceCallbacksEventsGetOutput
# mapDashboardInstanceCallbacksEventsListOutput
# mapDashboardInstanceCallbacksEventsListQuery
# mapDashboardInstanceCallbacksGetOutput
# mapDashboardInstanceCallbacksInstancesCreateBody
# mapDashboardInstanceCallbacksInstancesCreateOutput
# mapDashboardInstanceCallbacksInstancesDeleteOutput
# mapDashboardInstanceCallbacksInstancesListOutput
# mapDashboardInstanceCallbacksInstancesListQuery
# mapDashboardInstanceCallbacksListOutput
# mapDashboardInstanceCallbacksListQuery
# mapDashboardInstanceCallbacksNotificationsGetOutput
# mapDashboardInstanceCallbacksNotificationsListOutput
# mapDashboardInstanceCallbacksNotificationsListQuery
# mapDashboardInstanceCallbacksUpdateBody
# mapDashboardInstanceCallbacksUpdateOutput
# mapDashboardInstanceCustomProvidersCommitsCreateBody
# mapDashboardInstanceCustomProvidersCommitsCreateOutput
# mapDashboardInstanceCustomProvidersCommitsGetOutput
# mapDashboardInstanceCustomProvidersCommitsListOutput
# mapDashboardInstanceCustomProvidersCommitsListQuery
# mapDashboardInstanceCustomProvidersCreateBody
# mapDashboardInstanceCustomProvidersCreateOutput
# mapDashboardInstanceCustomProvidersDeploymentsGetLogsOutput
# mapDashboardInstanceCustomProvidersDeploymentsGetOutput
# mapDashboardInstanceCustomProvidersDeploymentsListOutput
# mapDashboardInstanceCustomProvidersDeploymentsListQuery
# mapDashboardInstanceCustomProvidersEnvironmentsGetOutput
# mapDashboardInstanceCustomProvidersEnvironmentsListOutput
# mapDashboardInstanceCustomProvidersEnvironmentsListQuery
# mapDashboardInstanceCustomProvidersGetOutput
# mapDashboardInstanceCustomProvidersListOutput
# mapDashboardInstanceCustomProvidersListQuery
# mapDashboardInstanceCustomProvidersUpdateBody
# mapDashboardInstanceCustomProvidersUpdateOutput
# mapDashboardInstanceCustomProvidersVersionsCreateBody
# mapDashboardInstanceCustomProvidersVersionsCreateOutput
# mapDashboardInstanceCustomProvidersVersionsGetOutput
# mapDashboardInstanceCustomProvidersVersionsListOutput
# mapDashboardInstanceCustomProvidersVersionsListQuery
# mapDashboardInstanceFileLinksCreateBody
# mapDashboardInstanceFileLinksCreateOutput
# mapDashboardInstanceFileLinksDeleteOutput
# mapDashboardInstanceFileLinksGetOutput
# mapDashboardInstanceFileLinksListOutput
# mapDashboardInstanceFileLinksListQuery
# mapDashboardInstanceFilesDeleteOutput
# mapDashboardInstanceFilesGetOutput
# mapDashboardInstanceFilesListOutput
# mapDashboardInstanceFilesListQuery
# mapDashboardInstanceIdentitiesCreateBody
# mapDashboardInstanceIdentitiesCreateOutput
# mapDashboardInstanceIdentitiesCredentialsCreateBody
# mapDashboardInstanceIdentitiesCredentialsCreateOutput
# mapDashboardInstanceIdentitiesCredentialsDeleteOutput
# mapDashboardInstanceIdentitiesCredentialsGetOutput
# mapDashboardInstanceIdentitiesCredentialsListOutput
# mapDashboardInstanceIdentitiesCredentialsListQuery
# mapDashboardInstanceIdentitiesCredentialsUpdateBody
# mapDashboardInstanceIdentitiesCredentialsUpdateOutput
# mapDashboardInstanceIdentitiesDelegationConfigsCreateBody
# mapDashboardInstanceIdentitiesDelegationConfigsCreateOutput
# mapDashboardInstanceIdentitiesDelegationConfigsDeleteOutput
# mapDashboardInstanceIdentitiesDelegationConfigsGetOutput
# mapDashboardInstanceIdentitiesDelegationConfigsListOutput
# mapDashboardInstanceIdentitiesDelegationConfigsListQuery
# mapDashboardInstanceIdentitiesDelegationConfigsUpdateBody
# mapDashboardInstanceIdentitiesDelegationConfigsUpdateOutput
# mapDashboardInstanceIdentitiesDelegationRequestsApproveOutput
# mapDashboardInstanceIdentitiesDelegationRequestsApproveQuery
# mapDashboardInstanceIdentitiesDelegationRequestsCreateBody
# mapDashboardInstanceIdentitiesDelegationRequestsCreateOutput
# mapDashboardInstanceIdentitiesDelegationRequestsDenyOutput
# mapDashboardInstanceIdentitiesDelegationRequestsDenyQuery
# mapDashboardInstanceIdentitiesDelegationRequestsGetOutput
# mapDashboardInstanceIdentitiesDelegationRequestsGetQuery
# mapDashboardInstanceIdentitiesDelegationRequestsListOutput
# mapDashboardInstanceIdentitiesDelegationRequestsListQuery
# mapDashboardInstanceIdentitiesDelegationsCreateBody
# mapDashboardInstanceIdentitiesDelegationsCreateOutput
# mapDashboardInstanceIdentitiesDelegationsGetOutput
# mapDashboardInstanceIdentitiesDelegationsListOutput
# mapDashboardInstanceIdentitiesDelegationsListQuery
# mapDashboardInstanceIdentitiesDelegationsRevokeOutput
# mapDashboardInstanceIdentitiesDeleteOutput
# mapDashboardInstanceIdentitiesGetOutput
# mapDashboardInstanceIdentitiesListOutput
# mapDashboardInstanceIdentitiesListQuery
# mapDashboardInstanceIdentitiesUpdateBody
# mapDashboardInstanceIdentitiesUpdateOutput
# mapDashboardInstanceIdentityActorsCreateBody
# mapDashboardInstanceIdentityActorsCreateOutput
# mapDashboardInstanceIdentityActorsDeleteOutput
# mapDashboardInstanceIdentityActorsGetOutput
# mapDashboardInstanceIdentityActorsListOutput
# mapDashboardInstanceIdentityActorsListQuery
# mapDashboardInstanceIdentityActorsUpdateBody
# mapDashboardInstanceIdentityActorsUpdateOutput
# mapDashboardInstanceInstanceGetOutput
# mapDashboardInstanceMagicMcpGroupsAddServersBody
# mapDashboardInstanceMagicMcpGroupsAddServersOutput
# mapDashboardInstanceMagicMcpGroupsCreateBody
# mapDashboardInstanceMagicMcpGroupsCreateOutput
# mapDashboardInstanceMagicMcpGroupsDeleteOutput
# mapDashboardInstanceMagicMcpGroupsGetOutput
# mapDashboardInstanceMagicMcpGroupsListOutput
# mapDashboardInstanceMagicMcpGroupsListQuery
# mapDashboardInstanceMagicMcpGroupsRemoveServersBody
# mapDashboardInstanceMagicMcpGroupsRemoveServersOutput
# mapDashboardInstanceMagicMcpGroupsUpdateBody
# mapDashboardInstanceMagicMcpGroupsUpdateOutput
# mapDashboardInstanceMagicMcpServersCreateBody
# mapDashboardInstanceMagicMcpServersCreateOutput
# mapDashboardInstanceMagicMcpServersDeleteOutput
# mapDashboardInstanceMagicMcpServersGetOutput
# mapDashboardInstanceMagicMcpServersListOutput
# mapDashboardInstanceMagicMcpServersListQuery
# mapDashboardInstanceMagicMcpServersUpdateBody
# mapDashboardInstanceMagicMcpServersUpdateOutput
# mapDashboardInstanceMagicMcpSessionsGetOutput
# mapDashboardInstanceMagicMcpSessionsListOutput
# mapDashboardInstanceMagicMcpSessionsListQuery
# mapDashboardInstanceMagicMcpTokensAddGroupsBody
# mapDashboardInstanceMagicMcpTokensAddGroupsOutput
# mapDashboardInstanceMagicMcpTokensCreateBody
# mapDashboardInstanceMagicMcpTokensCreateOutput
# mapDashboardInstanceMagicMcpTokensDeleteOutput
# mapDashboardInstanceMagicMcpTokensGetOutput
# mapDashboardInstanceMagicMcpTokensListOutput
# mapDashboardInstanceMagicMcpTokensListQuery
# mapDashboardInstanceMagicMcpTokensRemoveGroupsBody
# mapDashboardInstanceMagicMcpTokensRemoveGroupsOutput
# mapDashboardInstanceMagicMcpTokensUpdateBody
# mapDashboardInstanceMagicMcpTokensUpdateOutput
# mapDashboardInstancePortalsCreateBody
# mapDashboardInstancePortalsCreateOutput
# mapDashboardInstancePortalsDeleteOutput
# mapDashboardInstancePortalsGetOutput
# mapDashboardInstancePortalsListOutput
# mapDashboardInstancePortalsListQuery
# mapDashboardInstancePortalsUpdateBody
# mapDashboardInstancePortalsUpdateOutput
# mapDashboardInstanceProviderCategoriesGetOutput
# mapDashboardInstanceProviderCategoriesListOutput
# mapDashboardInstanceProviderCategoriesListQuery
# mapDashboardInstanceProviderCollectionsGetOutput
# mapDashboardInstanceProviderCollectionsListOutput
# mapDashboardInstanceProviderCollectionsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsDeleteOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsExportsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsGetSchemaQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsImportsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsListOutput
# mapDashboardInstanceProviderDeploymentsAuthConfigsListQuery
# mapDashboardInstanceProviderDeploymentsAuthConfigsUpdateBody
# mapDashboardInstanceProviderDeploymentsAuthConfigsUpdateOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsCreateBody
# mapDashboardInstanceProviderDeploymentsAuthCredentialsCreateOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsDeleteOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsGetOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsListOutput
# mapDashboardInstanceProviderDeploymentsAuthCredentialsListQuery
# mapDashboardInstanceProviderDeploymentsAuthCredentialsUpdateBody
# mapDashboardInstanceProviderDeploymentsAuthCredentialsUpdateOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsCreateBody
# mapDashboardInstanceProviderDeploymentsConfigVaultsCreateOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsDeleteOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsGetOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsListOutput
# mapDashboardInstanceProviderDeploymentsConfigVaultsListQuery
# mapDashboardInstanceProviderDeploymentsConfigVaultsUpdateBody
# mapDashboardInstanceProviderDeploymentsConfigVaultsUpdateOutput
# mapDashboardInstanceProviderDeploymentsConfigsCreateBody
# mapDashboardInstanceProviderDeploymentsConfigsCreateOutput
# mapDashboardInstanceProviderDeploymentsConfigsDeleteOutput
# mapDashboardInstanceProviderDeploymentsConfigsGetConfigSchemaOutput
# mapDashboardInstanceProviderDeploymentsConfigsGetConfigSchemaQuery
# mapDashboardInstanceProviderDeploymentsConfigsGetOutput
# mapDashboardInstanceProviderDeploymentsConfigsListOutput
# mapDashboardInstanceProviderDeploymentsConfigsListQuery
# mapDashboardInstanceProviderDeploymentsConfigsUpdateBody
# mapDashboardInstanceProviderDeploymentsConfigsUpdateOutput
# mapDashboardInstanceProviderDeploymentsCreateBody
# mapDashboardInstanceProviderDeploymentsCreateOutput
# mapDashboardInstanceProviderDeploymentsDeleteOutput
# mapDashboardInstanceProviderDeploymentsGetOutput
# mapDashboardInstanceProviderDeploymentsListOutput
# mapDashboardInstanceProviderDeploymentsListQuery
# mapDashboardInstanceProviderDeploymentsSetupSessionsCreateBody
# mapDashboardInstanceProviderDeploymentsSetupSessionsCreateOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsDeleteOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsGetOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsListOutput
# mapDashboardInstanceProviderDeploymentsSetupSessionsListQuery
# mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateBody
# mapDashboardInstanceProviderDeploymentsSetupSessionsUpdateOutput
# mapDashboardInstanceProviderDeploymentsUpdateBody
# mapDashboardInstanceProviderDeploymentsUpdateOutput
# mapDashboardInstanceProviderGroupsAddListingBody
# mapDashboardInstanceProviderGroupsAddListingOutput
# mapDashboardInstanceProviderGroupsCreateBody
# mapDashboardInstanceProviderGroupsCreateOutput
# mapDashboardInstanceProviderGroupsGetOutput
# mapDashboardInstanceProviderGroupsListOutput
# mapDashboardInstanceProviderGroupsListQuery
# mapDashboardInstanceProviderGroupsRemoveListingOutput
# mapDashboardInstanceProviderGroupsUpdateBody
# mapDashboardInstanceProviderGroupsUpdateOutput
# mapDashboardInstanceProviderListingsGetOutput
# mapDashboardInstanceProviderListingsListOutput
# mapDashboardInstanceProviderListingsListQuery
# mapDashboardInstanceProviderRunsGetLogsOutput
# mapDashboardInstanceProviderRunsGetOutput
# mapDashboardInstanceProviderRunsListOutput
# mapDashboardInstanceProviderRunsListQuery
# mapDashboardInstanceProviderTemplatesCreateBody
# mapDashboardInstanceProviderTemplatesCreateOutput
# mapDashboardInstanceProviderTemplatesDeleteOutput
# mapDashboardInstanceProviderTemplatesGetOutput
# mapDashboardInstanceProviderTemplatesListOutput
# mapDashboardInstanceProviderTemplatesListQuery
# mapDashboardInstanceProviderTemplatesUpdateBody
# mapDashboardInstanceProviderTemplatesUpdateOutput
# mapDashboardInstanceProvidersAuthMethodsGetOutput
# mapDashboardInstanceProvidersAuthMethodsListOutput
# mapDashboardInstanceProvidersAuthMethodsListQuery
# mapDashboardInstanceProvidersGetOutput
# mapDashboardInstanceProvidersListOutput
# mapDashboardInstanceProvidersListQuery
# mapDashboardInstanceProvidersSpecificationsGetOutput
# mapDashboardInstanceProvidersSpecificationsListOutput
# mapDashboardInstanceProvidersSpecificationsListQuery
# mapDashboardInstanceProvidersToolsGetOutput
# mapDashboardInstanceProvidersToolsListOutput
# mapDashboardInstanceProvidersToolsListQuery
# mapDashboardInstanceProvidersTriggersGetOutput
# mapDashboardInstanceProvidersTriggersListOutput
# mapDashboardInstanceProvidersTriggersListQuery
# mapDashboardInstanceProvidersVersionsGetOutput
# mapDashboardInstanceProvidersVersionsListOutput
# mapDashboardInstanceProvidersVersionsListQuery
# mapDashboardInstancePublishersGetOutput
# mapDashboardInstancePublishersListOutput
# mapDashboardInstancePublishersListQuery
# mapDashboardInstanceSessionTemplatesCreateBody
# mapDashboardInstanceSessionTemplatesCreateOutput
# mapDashboardInstanceSessionTemplatesGetOutput
# mapDashboardInstanceSessionTemplatesListOutput
# mapDashboardInstanceSessionTemplatesListQuery
# mapDashboardInstanceSessionTemplatesProvidersCreateBody
# mapDashboardInstanceSessionTemplatesProvidersCreateOutput
# mapDashboardInstanceSessionTemplatesProvidersDeleteOutput
# mapDashboardInstanceSessionTemplatesProvidersGetOutput
# mapDashboardInstanceSessionTemplatesProvidersListOutput
# mapDashboardInstanceSessionTemplatesProvidersListQuery
# mapDashboardInstanceSessionTemplatesProvidersUpdateBody
# mapDashboardInstanceSessionTemplatesProvidersUpdateOutput
# mapDashboardInstanceSessionTemplatesUpdateBody
# mapDashboardInstanceSessionTemplatesUpdateOutput
# mapDashboardInstanceSessionsConnectionsGetOutput
# mapDashboardInstanceSessionsConnectionsListOutput
# mapDashboardInstanceSessionsConnectionsListQuery
# mapDashboardInstanceSessionsCreateBody
# mapDashboardInstanceSessionsCreateOutput
# mapDashboardInstanceSessionsErrorGroupsGetOutput
# mapDashboardInstanceSessionsErrorGroupsListOutput
# mapDashboardInstanceSessionsErrorGroupsListQuery
# mapDashboardInstanceSessionsErrorsGetOutput
# mapDashboardInstanceSessionsErrorsListOutput
# mapDashboardInstanceSessionsErrorsListQuery
# mapDashboardInstanceSessionsEventsGetOutput
# mapDashboardInstanceSessionsEventsListOutput
# mapDashboardInstanceSessionsEventsListQuery
# mapDashboardInstanceSessionsGetOutput
# mapDashboardInstanceSessionsListOutput
# mapDashboardInstanceSessionsListQuery
# mapDashboardInstanceSessionsMessagesGetOutput
# mapDashboardInstanceSessionsMessagesListOutput
# mapDashboardInstanceSessionsMessagesListQuery
# mapDashboardInstanceSessionsParticipantsGetOutput
# mapDashboardInstanceSessionsParticipantsListOutput
# mapDashboardInstanceSessionsParticipantsListQuery
# mapDashboardInstanceSessionsProvidersCreateBody
# mapDashboardInstanceSessionsProvidersCreateOutput
# mapDashboardInstanceSessionsProvidersDeleteOutput
# mapDashboardInstanceSessionsProvidersGetOutput
# mapDashboardInstanceSessionsProvidersListOutput
# mapDashboardInstanceSessionsProvidersListQuery
# mapDashboardInstanceSessionsProvidersUpdateBody
# mapDashboardInstanceSessionsProvidersUpdateOutput
# mapDashboardInstanceSessionsUpdateBody
# mapDashboardInstanceSessionsUpdateOutput
# mapDashboardInstanceToolCallsCreateBody
# mapDashboardInstanceToolCallsCreateOutput
# mapDashboardInstanceToolCallsGetOutput
# mapDashboardInstanceToolCallsListOutput
# mapDashboardInstanceToolCallsListQuery
# mapInstancesGetOutput
# mapInstancesListOutput
# mapTokenGetOutput

# All types and mappers are available via:
# from .resources import *
# from .endpoints import *



from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
import dataclasses

@dataclass
class DashboardInstanceProviderDeploymentsUpdateOutputLockedVersion:
    object: str
    id: str
    version: str
    provider_id: str
    is_current: bool
    name: str
    created_at: datetime
    updated_at: datetime
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
    specification_id: Optional[str] = None
@dataclass
class DashboardInstanceProviderDeploymentsUpdateOutputDefaultConfig:
    object: str
    id: str
    is_default: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class DashboardInstanceProviderDeploymentsUpdateOutput:
    object: str
    id: str
    is_default: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
    locked_version: Optional[DashboardInstanceProviderDeploymentsUpdateOutputLockedVersion] = None
    default_config: Optional[DashboardInstanceProviderDeploymentsUpdateOutputDefaultConfig] = None


class mapDashboardInstanceProviderDeploymentsUpdateOutputLockedVersion:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsUpdateOutputLockedVersion:
        return DashboardInstanceProviderDeploymentsUpdateOutputLockedVersion(
        object=data.get('object'),
        id=data.get('id'),
        version=data.get('version'),
        provider_id=data.get('provider_id'),
        is_current=data.get('is_current'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        specification_id=data.get('specification_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsUpdateOutputLockedVersion, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsUpdateOutputDefaultConfig:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsUpdateOutputDefaultConfig:
        return DashboardInstanceProviderDeploymentsUpdateOutputDefaultConfig(
        object=data.get('object'),
        id=data.get('id'),
        is_default=data.get('is_default'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsUpdateOutputDefaultConfig, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapDashboardInstanceProviderDeploymentsUpdateOutput:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsUpdateOutput:
        return DashboardInstanceProviderDeploymentsUpdateOutput(
        object=data.get('object'),
        id=data.get('id'),
        is_default=data.get('is_default'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        locked_version=mapDashboardInstanceProviderDeploymentsUpdateOutputLockedVersion.from_dict(data.get('locked_version')) if data.get('locked_version') else None,
        default_config=mapDashboardInstanceProviderDeploymentsUpdateOutputDefaultConfig.from_dict(data.get('default_config')) if data.get('default_config') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsUpdateOutput, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)

@dataclass
class DashboardInstanceProviderDeploymentsUpdateBody:
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None


class mapDashboardInstanceProviderDeploymentsUpdateBody:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> DashboardInstanceProviderDeploymentsUpdateBody:
        return DashboardInstanceProviderDeploymentsUpdateBody(
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata')
        )

    @staticmethod
    def to_dict(value: Union[DashboardInstanceProviderDeploymentsUpdateBody, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)




from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
import dataclasses

@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputItemsScopes:
    identifier: str
    name: str
    description: str
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActorTeams:
    id: str
    name: str
    slug: str
    assignment_id: str
    created_at: datetime
    updated_at: datetime
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActor:
    object: str
    id: str
    type: str
    organization_id: str
    name: str
    image_url: str
    teams: List[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActorTeams]
    created_at: datetime
    updated_at: datetime
    email: Optional[str] = None
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstanceProject:
    object: str
    id: str
    status: str
    slug: str
    name: str
    organization_id: str
    created_at: datetime
    updated_at: datetime
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstance:
    object: str
    id: str
    slug: str
    name: str
    organization_id: str
    type: str
    created_at: datetime
    updated_at: datetime
    project: ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstanceProject
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessOrganization:
    object: str
    id: str
    type: str
    slug: str
    name: str
    image_url: str
    created_at: datetime
    updated_at: datetime
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessUser:
    object: str
    id: str
    status: str
    type: str
    email: str
    name: str
    first_name: str
    last_name: str
    image_url: str
    created_at: datetime
    updated_at: datetime
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccess:
    object: str
    id: str
    status: str
    type: str
    name: str
    last_used_at: datetime
    created_at: datetime
    updated_at: datetime
    deleted_at: datetime
    actor: Optional[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActor] = None
    instance: Optional[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstance] = None
    organization: Optional[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessOrganization] = None
    user: Optional[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessUser] = None
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputItems:
    object: str
    id: str
    status: str
    service_account_id: str
    scopes: List[ManagementOrganizationServiceAccountsCredentialsListOutputItemsScopes]
    machine_access: ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccess
    created_at: datetime
    updated_at: datetime
    last_used_at: Optional[datetime] = None
    revoked_at: Optional[datetime] = None
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutputPagination:
    has_more_before: bool
    has_more_after: bool
@dataclass
class ManagementOrganizationServiceAccountsCredentialsListOutput:
    items: List[ManagementOrganizationServiceAccountsCredentialsListOutputItems]
    pagination: ManagementOrganizationServiceAccountsCredentialsListOutputPagination


class mapManagementOrganizationServiceAccountsCredentialsListOutputItemsScopes:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputItemsScopes:
        return ManagementOrganizationServiceAccountsCredentialsListOutputItemsScopes(
        identifier=data.get('identifier'),
        name=data.get('name'),
        description=data.get('description')
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputItemsScopes, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActorTeams:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActorTeams:
        return ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActorTeams(
        id=data.get('id'),
        name=data.get('name'),
        slug=data.get('slug'),
        assignment_id=data.get('assignment_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActorTeams, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActor:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActor:
        return ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActor(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        organization_id=data.get('organization_id'),
        name=data.get('name'),
        email=data.get('email'),
        image_url=data.get('image_url'),
        teams=[mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActorTeams.from_dict(item) for item in data.get('teams', []) if item],
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActor, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstanceProject:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstanceProject:
        return ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstanceProject(
        object=data.get('object'),
        id=data.get('id'),
        status=data.get('status'),
        slug=data.get('slug'),
        name=data.get('name'),
        organization_id=data.get('organization_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstanceProject, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstance:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstance:
        return ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstance(
        object=data.get('object'),
        id=data.get('id'),
        slug=data.get('slug'),
        name=data.get('name'),
        organization_id=data.get('organization_id'),
        type=data.get('type'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None,
        project=mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstanceProject.from_dict(data.get('project')) if data.get('project') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstance, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessOrganization:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessOrganization:
        return ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessOrganization(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        slug=data.get('slug'),
        name=data.get('name'),
        image_url=data.get('image_url'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessOrganization, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessUser:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessUser:
        return ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessUser(
        object=data.get('object'),
        id=data.get('id'),
        status=data.get('status'),
        type=data.get('type'),
        email=data.get('email'),
        name=data.get('name'),
        first_name=data.get('first_name'),
        last_name=data.get('last_name'),
        image_url=data.get('image_url'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessUser, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccess:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccess:
        return ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccess(
        object=data.get('object'),
        id=data.get('id'),
        status=data.get('status'),
        type=data.get('type'),
        name=data.get('name'),
        last_used_at=datetime.fromisoformat(data.get('last_used_at').replace('Z', '+00:00')) if data.get('last_used_at') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None,
        deleted_at=datetime.fromisoformat(data.get('deleted_at').replace('Z', '+00:00')) if data.get('deleted_at') else None,
        actor=mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessActor.from_dict(data.get('actor')) if data.get('actor') else None,
        instance=mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessInstance.from_dict(data.get('instance')) if data.get('instance') else None,
        organization=mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessOrganization.from_dict(data.get('organization')) if data.get('organization') else None,
        user=mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccessUser.from_dict(data.get('user')) if data.get('user') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccess, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutputItems:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputItems:
        return ManagementOrganizationServiceAccountsCredentialsListOutputItems(
        object=data.get('object'),
        id=data.get('id'),
        status=data.get('status'),
        service_account_id=data.get('service_account_id'),
        scopes=[mapManagementOrganizationServiceAccountsCredentialsListOutputItemsScopes.from_dict(item) for item in data.get('scopes', []) if item],
        machine_access=mapManagementOrganizationServiceAccountsCredentialsListOutputItemsMachineAccess.from_dict(data.get('machine_access')) if data.get('machine_access') else None,
        last_used_at=datetime.fromisoformat(data.get('last_used_at').replace('Z', '+00:00')) if data.get('last_used_at') else None,
        revoked_at=datetime.fromisoformat(data.get('revoked_at').replace('Z', '+00:00')) if data.get('revoked_at') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputItems, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutputPagination:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutputPagination:
        return ManagementOrganizationServiceAccountsCredentialsListOutputPagination(
        has_more_before=data.get('has_more_before'),
        has_more_after=data.get('has_more_after')
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutputPagination, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementOrganizationServiceAccountsCredentialsListOutput:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListOutput:
        return ManagementOrganizationServiceAccountsCredentialsListOutput(
        items=[mapManagementOrganizationServiceAccountsCredentialsListOutputItems.from_dict(item) for item in data.get('items', []) if item],
        pagination=mapManagementOrganizationServiceAccountsCredentialsListOutputPagination.from_dict(data.get('pagination')) if data.get('pagination') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListOutput, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)

@dataclass
class ManagementOrganizationServiceAccountsCredentialsListQuery:
    limit: Optional[float] = None
    after: Optional[str] = None
    before: Optional[str] = None
    cursor: Optional[str] = None
    order: Optional[str] = None
    status: Optional[Union[str, List[str]]] = None


class mapManagementOrganizationServiceAccountsCredentialsListQuery:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementOrganizationServiceAccountsCredentialsListQuery:
        return ManagementOrganizationServiceAccountsCredentialsListQuery(
        limit=data.get('limit'),
        after=data.get('after'),
        before=data.get('before'),
        cursor=data.get('cursor'),
        order=data.get('order'),
        status=data.get('status')
        )

    @staticmethod
    def to_dict(value: Union[ManagementOrganizationServiceAccountsCredentialsListQuery, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)




from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
import dataclasses

@dataclass
class ManagementInstanceProviderDeploymentsAuthConfigsGetOutputDeploymentPreview:
    object: str
    id: str
    is_default: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class ManagementInstanceProviderDeploymentsAuthConfigsGetOutputCredentials:
    object: str
    id: str
    type: str
    is_default: bool
    is_managed: bool
    provider_id: str
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
@dataclass
class ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodInputSchema:
    type: str
    schema: Dict[str, Any]
@dataclass
class ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodOutputSchema:
    type: str
    schema: Dict[str, Any]
@dataclass
class ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodScopes:
    object: str
    id: str
    scope: str
    name: str
    description: Optional[str] = None
@dataclass
class ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethod:
    object: str
    id: str
    type: str
    key: str
    name: str
    capabilities: Dict[str, Any]
    provider_id: str
    provider_specification_id: str
    created_at: datetime
    updated_at: datetime
    description: Optional[str] = None
    input_schema: Optional[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodInputSchema] = None
    output_schema: Optional[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodOutputSchema] = None
    scopes: Optional[List[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodScopes]] = None
@dataclass
class ManagementInstanceProviderDeploymentsAuthConfigsGetOutput:
    object: str
    id: str
    type: str
    source: str
    status: str
    is_default: bool
    provider_id: str
    auth_method: ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethod
    created_at: datetime
    updated_at: datetime
    name: Optional[str] = None
    description: Optional[str] = None
    metadata: Optional[Dict[str, Any]] = None
    deployment_preview: Optional[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputDeploymentPreview] = None
    credentials: Optional[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputCredentials] = None


class mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputDeploymentPreview:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsAuthConfigsGetOutputDeploymentPreview:
        return ManagementInstanceProviderDeploymentsAuthConfigsGetOutputDeploymentPreview(
        object=data.get('object'),
        id=data.get('id'),
        is_default=data.get('is_default'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputDeploymentPreview, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputCredentials:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsAuthConfigsGetOutputCredentials:
        return ManagementInstanceProviderDeploymentsAuthConfigsGetOutputCredentials(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        is_default=data.get('is_default'),
        is_managed=data.get('is_managed'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        provider_id=data.get('provider_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputCredentials, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodInputSchema:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodInputSchema:
        return ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodInputSchema(
        type=data.get('type'),
        schema=data.get('schema')
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodInputSchema, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodOutputSchema:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodOutputSchema:
        return ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodOutputSchema(
        type=data.get('type'),
        schema=data.get('schema')
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodOutputSchema, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodScopes:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodScopes:
        return ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodScopes(
        object=data.get('object'),
        id=data.get('id'),
        scope=data.get('scope'),
        name=data.get('name'),
        description=data.get('description')
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodScopes, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethod:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethod:
        return ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethod(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        key=data.get('key'),
        name=data.get('name'),
        description=data.get('description'),
        capabilities=data.get('capabilities'),
        input_schema=mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodInputSchema.from_dict(data.get('input_schema')) if data.get('input_schema') else None,
        output_schema=mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodOutputSchema.from_dict(data.get('output_schema')) if data.get('output_schema') else None,
        scopes=[mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethodScopes.from_dict(item) for item in data.get('scopes', []) if item],
        provider_id=data.get('provider_id'),
        provider_specification_id=data.get('provider_specification_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethod, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapManagementInstanceProviderDeploymentsAuthConfigsGetOutput:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> ManagementInstanceProviderDeploymentsAuthConfigsGetOutput:
        return ManagementInstanceProviderDeploymentsAuthConfigsGetOutput(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        source=data.get('source'),
        status=data.get('status'),
        is_default=data.get('is_default'),
        provider_id=data.get('provider_id'),
        name=data.get('name'),
        description=data.get('description'),
        metadata=data.get('metadata'),
        deployment_preview=mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputDeploymentPreview.from_dict(data.get('deployment_preview')) if data.get('deployment_preview') else None,
        credentials=mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputCredentials.from_dict(data.get('credentials')) if data.get('credentials') else None,
        auth_method=mapManagementInstanceProviderDeploymentsAuthConfigsGetOutputAuthMethod.from_dict(data.get('auth_method')) if data.get('auth_method') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[ManagementInstanceProviderDeploymentsAuthConfigsGetOutput, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)




from dataclasses import dataclass
from typing import Any, Dict, List, Optional, Union
from datetime import datetime
import dataclasses

@dataclass
class CustomProvidersVersionsCreateOutputConfigSchema:
    type: str
    schema: Dict[str, Any]
@dataclass
class CustomProvidersVersionsCreateOutputConfig:
    object: str
    schema: CustomProvidersVersionsCreateOutputConfigSchema
    transformer: str
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentCommit:
    object: str
    id: str
    type: str
    created_at: datetime
    message: Optional[str] = None
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepositoryProvider:
    object: str
    type: str
    id: str
    name: str
    owner: str
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepository:
    object: str
    id: str
    provider: CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepositoryProvider
    url: str
    is_private: bool
    default_branch: str
    created_at: datetime
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLink:
    object: str
    is_linked: str
    repository: CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepository
    path: Optional[str] = None
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentImmutableBucket:
    object: str
    id: str
    is_immutable: bool
    is_read_only: bool
    created_at: datetime
    scm_repo_link: Optional[CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLink] = None
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentActor:
    object: str
    id: str
    type: str
    identifier: str
    name: str
    created_at: datetime
    organization_actor_id: Optional[str] = None
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentScmPushActor:
    object: str
    id: str
    external_id: Optional[str] = None
    name: Optional[str] = None
    email: Optional[str] = None
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentScmPushCommit:
    object: str
    id: str
    sha: str
    branch: str
    created_at: datetime
    message: Optional[str] = None
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentScmPushRepositoryProvider:
    object: str
    type: str
    id: str
    name: str
    owner: str
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentScmPushRepository:
    object: str
    id: str
    provider: CustomProvidersVersionsCreateOutputDeploymentScmPushRepositoryProvider
    url: str
    is_private: bool
    default_branch: str
    created_at: datetime
@dataclass
class CustomProvidersVersionsCreateOutputDeploymentScmPush:
    object: str
    id: str
    actor: CustomProvidersVersionsCreateOutputDeploymentScmPushActor
    commit: CustomProvidersVersionsCreateOutputDeploymentScmPushCommit
    repository: CustomProvidersVersionsCreateOutputDeploymentScmPushRepository
    created_at: datetime
@dataclass
class CustomProvidersVersionsCreateOutputDeployment:
    object: str
    id: str
    status: str
    trigger: str
    custom_provider_id: str
    actor: CustomProvidersVersionsCreateOutputDeploymentActor
    created_at: datetime
    updated_at: datetime
    provider_id: Optional[str] = None
    custom_provider_version_id: Optional[str] = None
    commit: Optional[CustomProvidersVersionsCreateOutputDeploymentCommit] = None
    immutable_bucket: Optional[CustomProvidersVersionsCreateOutputDeploymentImmutableBucket] = None
    scm_push: Optional[CustomProvidersVersionsCreateOutputDeploymentScmPush] = None
@dataclass
class CustomProvidersVersionsCreateOutputEnvironmentsEnvironment:
    object: str
    id: str
    custom_provider_id: str
    instance_id: str
    created_at: datetime
    updated_at: datetime
    provider_id: Optional[str] = None
    current_provider_version_id: Optional[str] = None
@dataclass
class CustomProvidersVersionsCreateOutputEnvironments:
    object: str
    id: str
    is_current_version_for_environment: bool
    environment: CustomProvidersVersionsCreateOutputEnvironmentsEnvironment
@dataclass
class CustomProvidersVersionsCreateOutputActor:
    object: str
    id: str
    type: str
    identifier: str
    name: str
    created_at: datetime
    organization_actor_id: Optional[str] = None
@dataclass
class CustomProvidersVersionsCreateOutputContainerImage:
    container_registry: str
    container_image_tag: str
    container_image: str
@dataclass
class CustomProvidersVersionsCreateOutputRemoteMcpServer:
    url: str
    transport: str
@dataclass
class CustomProvidersVersionsCreateOutput:
    object: str
    id: str
    status: str
    index: float
    identifier: str
    deployment: CustomProvidersVersionsCreateOutputDeployment
    environments: List[CustomProvidersVersionsCreateOutputEnvironments]
    custom_provider_id: str
    actor: CustomProvidersVersionsCreateOutputActor
    created_at: datetime
    updated_at: datetime
    config: Optional[CustomProvidersVersionsCreateOutputConfig] = None
    provider_id: Optional[str] = None
    container_image: Optional[CustomProvidersVersionsCreateOutputContainerImage] = None
    remote_mcp_server: Optional[CustomProvidersVersionsCreateOutputRemoteMcpServer] = None


class mapCustomProvidersVersionsCreateOutputConfigSchema:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputConfigSchema:
        return CustomProvidersVersionsCreateOutputConfigSchema(
        type=data.get('type'),
        schema=data.get('schema')
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputConfigSchema, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputConfig:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputConfig:
        return CustomProvidersVersionsCreateOutputConfig(
        object=data.get('object'),
        schema=mapCustomProvidersVersionsCreateOutputConfigSchema.from_dict(data.get('schema')) if data.get('schema') else None,
        transformer=data.get('transformer')
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputConfig, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentCommit:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentCommit:
        return CustomProvidersVersionsCreateOutputDeploymentCommit(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        message=data.get('message'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentCommit, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepositoryProvider:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepositoryProvider:
        return CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepositoryProvider(
        object=data.get('object'),
        type=data.get('type'),
        id=data.get('id'),
        name=data.get('name'),
        owner=data.get('owner')
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepositoryProvider, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepository:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepository:
        return CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepository(
        object=data.get('object'),
        id=data.get('id'),
        provider=mapCustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepositoryProvider.from_dict(data.get('provider')) if data.get('provider') else None,
        url=data.get('url'),
        is_private=data.get('is_private'),
        default_branch=data.get('default_branch'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepository, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLink:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLink:
        return CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLink(
        object=data.get('object'),
        is_linked=data.get('is_linked'),
        path=data.get('path'),
        repository=mapCustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLinkRepository.from_dict(data.get('repository')) if data.get('repository') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLink, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentImmutableBucket:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentImmutableBucket:
        return CustomProvidersVersionsCreateOutputDeploymentImmutableBucket(
        object=data.get('object'),
        id=data.get('id'),
        is_immutable=data.get('is_immutable'),
        is_read_only=data.get('is_read_only'),
        scm_repo_link=mapCustomProvidersVersionsCreateOutputDeploymentImmutableBucketScmRepoLink.from_dict(data.get('scm_repo_link')) if data.get('scm_repo_link') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentImmutableBucket, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentActor:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentActor:
        return CustomProvidersVersionsCreateOutputDeploymentActor(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        identifier=data.get('identifier'),
        name=data.get('name'),
        organization_actor_id=data.get('organization_actor_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentActor, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentScmPushActor:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentScmPushActor:
        return CustomProvidersVersionsCreateOutputDeploymentScmPushActor(
        object=data.get('object'),
        id=data.get('id'),
        external_id=data.get('external_id'),
        name=data.get('name'),
        email=data.get('email')
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentScmPushActor, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentScmPushCommit:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentScmPushCommit:
        return CustomProvidersVersionsCreateOutputDeploymentScmPushCommit(
        object=data.get('object'),
        id=data.get('id'),
        sha=data.get('sha'),
        branch=data.get('branch'),
        message=data.get('message'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentScmPushCommit, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentScmPushRepositoryProvider:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentScmPushRepositoryProvider:
        return CustomProvidersVersionsCreateOutputDeploymentScmPushRepositoryProvider(
        object=data.get('object'),
        type=data.get('type'),
        id=data.get('id'),
        name=data.get('name'),
        owner=data.get('owner')
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentScmPushRepositoryProvider, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentScmPushRepository:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentScmPushRepository:
        return CustomProvidersVersionsCreateOutputDeploymentScmPushRepository(
        object=data.get('object'),
        id=data.get('id'),
        provider=mapCustomProvidersVersionsCreateOutputDeploymentScmPushRepositoryProvider.from_dict(data.get('provider')) if data.get('provider') else None,
        url=data.get('url'),
        is_private=data.get('is_private'),
        default_branch=data.get('default_branch'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentScmPushRepository, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeploymentScmPush:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeploymentScmPush:
        return CustomProvidersVersionsCreateOutputDeploymentScmPush(
        object=data.get('object'),
        id=data.get('id'),
        actor=mapCustomProvidersVersionsCreateOutputDeploymentScmPushActor.from_dict(data.get('actor')) if data.get('actor') else None,
        commit=mapCustomProvidersVersionsCreateOutputDeploymentScmPushCommit.from_dict(data.get('commit')) if data.get('commit') else None,
        repository=mapCustomProvidersVersionsCreateOutputDeploymentScmPushRepository.from_dict(data.get('repository')) if data.get('repository') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeploymentScmPush, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputDeployment:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputDeployment:
        return CustomProvidersVersionsCreateOutputDeployment(
        object=data.get('object'),
        id=data.get('id'),
        status=data.get('status'),
        trigger=data.get('trigger'),
        custom_provider_id=data.get('custom_provider_id'),
        provider_id=data.get('provider_id'),
        custom_provider_version_id=data.get('custom_provider_version_id'),
        commit=mapCustomProvidersVersionsCreateOutputDeploymentCommit.from_dict(data.get('commit')) if data.get('commit') else None,
        immutable_bucket=mapCustomProvidersVersionsCreateOutputDeploymentImmutableBucket.from_dict(data.get('immutable_bucket')) if data.get('immutable_bucket') else None,
        actor=mapCustomProvidersVersionsCreateOutputDeploymentActor.from_dict(data.get('actor')) if data.get('actor') else None,
        scm_push=mapCustomProvidersVersionsCreateOutputDeploymentScmPush.from_dict(data.get('scm_push')) if data.get('scm_push') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputDeployment, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputEnvironmentsEnvironment:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputEnvironmentsEnvironment:
        return CustomProvidersVersionsCreateOutputEnvironmentsEnvironment(
        object=data.get('object'),
        id=data.get('id'),
        custom_provider_id=data.get('custom_provider_id'),
        provider_id=data.get('provider_id'),
        current_provider_version_id=data.get('current_provider_version_id'),
        instance_id=data.get('instance_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputEnvironmentsEnvironment, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputEnvironments:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputEnvironments:
        return CustomProvidersVersionsCreateOutputEnvironments(
        object=data.get('object'),
        id=data.get('id'),
        is_current_version_for_environment=data.get('is_current_version_for_environment'),
        environment=mapCustomProvidersVersionsCreateOutputEnvironmentsEnvironment.from_dict(data.get('environment')) if data.get('environment') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputEnvironments, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputActor:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputActor:
        return CustomProvidersVersionsCreateOutputActor(
        object=data.get('object'),
        id=data.get('id'),
        type=data.get('type'),
        identifier=data.get('identifier'),
        name=data.get('name'),
        organization_actor_id=data.get('organization_actor_id'),
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputActor, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputContainerImage:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputContainerImage:
        return CustomProvidersVersionsCreateOutputContainerImage(
        container_registry=data.get('container_registry'),
        container_image_tag=data.get('container_image_tag'),
        container_image=data.get('container_image')
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputContainerImage, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutputRemoteMcpServer:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutputRemoteMcpServer:
        return CustomProvidersVersionsCreateOutputRemoteMcpServer(
        url=data.get('url'),
        transport=data.get('transport')
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutputRemoteMcpServer, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateOutput:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateOutput:
        return CustomProvidersVersionsCreateOutput(
        object=data.get('object'),
        id=data.get('id'),
        status=data.get('status'),
        config=mapCustomProvidersVersionsCreateOutputConfig.from_dict(data.get('config')) if data.get('config') else None,
        index=data.get('index'),
        identifier=data.get('identifier'),
        deployment=mapCustomProvidersVersionsCreateOutputDeployment.from_dict(data.get('deployment')) if data.get('deployment') else None,
        environments=[mapCustomProvidersVersionsCreateOutputEnvironments.from_dict(item) for item in data.get('environments', []) if item],
        custom_provider_id=data.get('custom_provider_id'),
        provider_id=data.get('provider_id'),
        actor=mapCustomProvidersVersionsCreateOutputActor.from_dict(data.get('actor')) if data.get('actor') else None,
        container_image=mapCustomProvidersVersionsCreateOutputContainerImage.from_dict(data.get('container_image')) if data.get('container_image') else None,
        remote_mcp_server=mapCustomProvidersVersionsCreateOutputRemoteMcpServer.from_dict(data.get('remote_mcp_server')) if data.get('remote_mcp_server') else None,
        created_at=datetime.fromisoformat(data.get('created_at').replace('Z', '+00:00')) if data.get('created_at') else None,
        updated_at=datetime.fromisoformat(data.get('updated_at').replace('Z', '+00:00')) if data.get('updated_at') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateOutput, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)

@dataclass
class CustomProvidersVersionsCreateBodyConfig:
    schema: Dict[str, Any]
    transformer: str
@dataclass
class CustomProvidersVersionsCreateBody:
    custom_provider_id: str
    from_: Dict[str, Any]
    config: Optional[CustomProvidersVersionsCreateBodyConfig] = None


class mapCustomProvidersVersionsCreateBodyConfig:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateBodyConfig:
        return CustomProvidersVersionsCreateBodyConfig(
        schema=data.get('schema'),
        transformer=data.get('transformer')
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateBodyConfig, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        return dataclasses.asdict(value)

class mapCustomProvidersVersionsCreateBody:
    @staticmethod
    def from_dict(data: Dict[str, Any]) -> CustomProvidersVersionsCreateBody:
        return CustomProvidersVersionsCreateBody(
        custom_provider_id=data.get('custom_provider_id'),
        from_=data.get('from'),
        config=mapCustomProvidersVersionsCreateBodyConfig.from_dict(data.get('config')) if data.get('config') else None
        )

    @staticmethod
    def to_dict(value: Union[CustomProvidersVersionsCreateBody, Dict[str, Any], None]) -> Optional[Dict[str, Any]]:
        if value is None:
            return None
        if isinstance(value, dict):
            return value
        # assume dataclass for generated models
        return dataclasses.asdict(value)

